# lost_cat - medical
Lost cat is a package to scan a variety of locations and report back the files, metadata, and summary contents as needed.

This is a library of processors, parsers, and other tools for handling medical storage, files, and processing.
